@@ -6,7 +6,7 @@ fn main() {
     let out_dir = env::var_os("OUT_DIR").expect("OUT_DIR env var missing");
     let dest_path = Path::new(&out_dir).join("style.css");
     fs::write(
-        &dest_path,
+        dest_path,
         grass::from_string(
             include_str!("data/style.scss").to_string(),
             &grass::Options::default(),
