@@ -1,16 +1,15 @@
-use std::io;
-use std::io::Write;
+use std::io::{self, Write};
 use std::net::{IpAddr, SocketAddr, TcpListener};
 use std::thread;
 use std::time::Duration;
 
 use actix_files::NamedFile;
-use actix_web::web;
-use actix_web::{http::header::ContentType, Responder};
-use actix_web::{middleware, App, HttpRequest, HttpResponse};
+use actix_web::{
+    http::header::ContentType, middleware, web, App, HttpRequest, HttpResponse, Responder,
+};
 use actix_web_httpauth::middleware::HttpAuthentication;
 use anyhow::Result;
-use clap::{crate_version, IntoApp, Parser};
+use clap::{crate_version, CommandFactory, Parser};
 use fast_qr::QRBuilder;
 use log::{error, warn};
 use yansi::{Color, Paint};
@@ -124,7 +123,7 @@ async fn run(miniserve_config: MiniserveConfig) -> Result<(), ContextualError> {
             .flush()
             .map_err(|e| ContextualError::IoError("Failed to write data".to_string(), e))?;
         for c in "3… 2… 1… \n".chars() {
-            print!("{}", c);
+            print!("{c}");
             io::stdout()
                 .flush()
                 .map_err(|e| ContextualError::IoError("Failed to write data".to_string(), e))?;
@@ -162,8 +161,8 @@ async fn run(miniserve_config: MiniserveConfig) -> Result<(), ContextualError> {
                 IpAddr::V6(_) => format!("[{}]:{}", addr, miniserve_config.port),
             })
             .map(|addr| match miniserve_config.tls_rustls_config {
-                Some(_) => format!("https://{}", addr),
-                None => format!("http://{}", addr),
+                Some(_) => format!("https://{addr}"),
+                None => format!("http://{addr}"),
             })
             .map(|url| format!("{}{}", url, miniserve_config.route_prefix))
             .collect::<Vec<_>>()
@@ -202,9 +201,8 @@ async fn run(miniserve_config: MiniserveConfig) -> Result<(), ContextualError> {
     });
 
     let srv = socket_addresses.iter().try_fold(srv, |srv, addr| {
-        let listener = create_tcp_listener(*addr).map_err(|e| {
-            ContextualError::IoError(format!("Failed to bind server to {}", addr), e)
-        })?;
+        let listener = create_tcp_listener(*addr)
+            .map_err(|e| ContextualError::IoError(format!("Failed to bind server to {addr}"), e))?;
 
         #[cfg(feature = "tls")]
         let srv = match &miniserve_config.tls_rustls_config {
@@ -215,7 +213,7 @@ async fn run(miniserve_config: MiniserveConfig) -> Result<(), ContextualError> {
         #[cfg(not(feature = "tls"))]
         let srv = srv.listen(listener);
 
-        srv.map_err(|e| ContextualError::IoError(format!("Failed to bind server to {}", addr), e))
+        srv.map_err(|e| ContextualError::IoError(format!("Failed to bind server to {addr}"), e))
     })?;
 
     let srv = srv.shutdown_timeout(0).run();
@@ -298,7 +296,7 @@ fn configure_app(app: &mut web::ServiceConfig, conf: &MiniserveConfig) {
             // Note: --spa requires --index in clap.
             if conf.spa {
                 files = files.default_handler(
-                    NamedFile::open(&conf.path.join(index_file))
+                    NamedFile::open(conf.path.join(index_file))
                         .expect("Can't open SPA index file."),
                 );
             }
